@@ -5,7 +5,7 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Sept 2002
-/// @version $Id: GUIEdge.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: GUIEdge.cpp 16290 2014-05-05 12:38:38Z namdre $
 ///
 // A road/street connecting two junctions (gui-version)
 /****************************************************************************/
@@ -73,8 +73,8 @@
 // included modules
 // ===========================================================================
 GUIEdge::GUIEdge(const std::string& id, int numericalID,
-                 const EdgeBasicFunction function, const std::string& streetName)
-    : MSEdge(id, numericalID, function, streetName),
+                 const EdgeBasicFunction function, const std::string& streetName, const std::string& edgeType)
+    : MSEdge(id, numericalID, function, streetName, edgeType),
       GUIGlObject(GLO_EDGE, id) {}
 
 
@@ -292,9 +292,10 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
 #endif
     // (optionally) draw the name and/or the street name
     const bool drawEdgeName = s.edgeName.show && myFunction == EDGEFUNCTION_NORMAL;
-    const bool drawInternalEdgeName = s.internalEdgeName.show && myFunction != EDGEFUNCTION_NORMAL;
+    const bool drawInternalEdgeName = s.internalEdgeName.show && myFunction == EDGEFUNCTION_INTERNAL;
+    const bool drawCwaEdgeName = s.cwaEdgeName.show && (myFunction == EDGEFUNCTION_CROSSING || myFunction == EDGEFUNCTION_WALKINGAREA);
     const bool drawStreetName = s.streetName.show && myStreetName != "";
-    if (drawEdgeName || drawInternalEdgeName || drawStreetName) {
+    if (drawEdgeName || drawInternalEdgeName || drawCwaEdgeName || drawStreetName) {
         GUILane* lane1 = dynamic_cast<GUILane*>((*myLanes)[0]);
         GUILane* lane2 = dynamic_cast<GUILane*>((*myLanes).back());
         if (lane1 != 0 && lane2 != 0) {
@@ -310,6 +311,8 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
                 drawName(p, s.scale, s.edgeName, angle);
             } else if (drawInternalEdgeName) {
                 drawName(p, s.scale, s.internalEdgeName, angle);
+            } else if (drawCwaEdgeName) {
+                drawName(p, s.scale, s.cwaEdgeName, angle);
             }
             if (drawStreetName) {
                 GLHelper::drawText(getStreetName(), p, GLO_MAX,
@@ -317,13 +320,15 @@ GUIEdge::drawGL(const GUIVisualizationSettings& s) const {
             }
         }
     }
-    myLock.lock();
-    for (std::set<MSPerson*>::const_iterator i = myPersons.begin(); i != myPersons.end(); ++i) {
-        GUIPerson* person = dynamic_cast<GUIPerson*>(*i);
-        assert(person != 0);
-        person->drawGL(s);
+    if (s.scale > s.minPersonSize) {
+        myLock.lock();
+        for (std::set<MSPerson*>::const_iterator i = myPersons.begin(); i != myPersons.end(); ++i) {
+            GUIPerson* person = dynamic_cast<GUIPerson*>(*i);
+            assert(person != 0);
+            person->drawGL(s);
+        }
+        myLock.unlock();
     }
-    myLock.unlock();
 }
 
 #ifdef HAVE_INTERNAL
