@@ -5,7 +5,7 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Sept 2002
-/// @version $Id: GUIEdge.h 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: GUIEdge.h 16290 2014-05-05 12:38:38Z namdre $
 ///
 // A road/street connecting two junctions (gui-version)
 /****************************************************************************/
@@ -66,7 +66,7 @@ public:
      * @see MSEdge
      */
     GUIEdge(const std::string& id, int numericalID,
-            const EdgeBasicFunction function, const std::string& streetName);
+            const EdgeBasicFunction function, const std::string& streetName, const std::string& edgeType);
 
 
     /// @brief Destructor.
@@ -137,12 +137,12 @@ public:
     //@}
 
 
-    void addPerson(MSPerson* p) {
+    void addPerson(MSPerson* p) const {
         AbstractMutex::ScopedLocker locker(myLock);
         MSEdge::addPerson(p);
     }
 
-    void removePerson(MSPerson* p) {
+    void removePerson(MSPerson* p) const {
         AbstractMutex::ScopedLocker locker(myLock);
         MSEdge::removePerson(p);
     }
