@@ -6,7 +6,7 @@
 /// @author  Sascha Krieg
 /// @author  Michael Behrisch
 /// @date    Fri, 08.10.2013
-/// @version $Id: MSLCM_LC2013.cpp 15861 2014-03-06 16:45:02Z namdre $
+/// @version $Id: MSLCM_LC2013.cpp 16560 2014-06-09 20:54:15Z behrisch $
 ///
 // A lane change model developed by D. Krajzewicz, J. Erdmann et al. between 2004 and 2013
 /****************************************************************************/
@@ -86,9 +86,7 @@
 #define KEEP_RIGHT_TIME (SUMOReal)5.0 // the number of seconds after which a vehicle should move to the right lane
 #define KEEP_RIGHT_ACCEPTANCE (SUMOReal)2.0 // calibration factor for determining the desire to keep right
 
-#define OVERTAKE_RIGHT_FORBIDDEN true // This holds true for german traffic but should be made configurable to model american traffic
-
-
+#define RELGAIN_NORMALIZATION_MIN_SPEED (SUMOReal)10.0
 
 // ===========================================================================
 // member method definitions
@@ -436,6 +434,7 @@ MSLCM_LC2013::_wantsChange(
     const bool changeToBest = (right && bestLaneOffset < 0) || (!right && bestLaneOffset > 0);
     // keep information about being a leader/follower
     int ret = (myOwnState & 0xffff0000);
+    int req = 0; // the request to change or stay
 
     ret = slowDownForBlocked(lastBlocked, ret);
     if (lastBlocked != firstBlocked) {
@@ -503,7 +502,7 @@ MSLCM_LC2013::_wantsChange(
         ret = ret | lca | LCA_STRATEGIC | LCA_URGENT;
     } else {
 
-        if (OVERTAKE_RIGHT_FORBIDDEN && !right && !myVehicle.congested() && neighLead.first != 0) {
+        if (!myAllowOvertakingRight && !right && !myVehicle.congested() && neighLead.first != 0) {
             // check for slower leader on the left. we should not overtake but
             // rather move left ourselves (unless congested)
             MSVehicle* nv = neighLead.first;
@@ -559,7 +558,7 @@ MSLCM_LC2013::_wantsChange(
         }
 
         const SUMOReal remainingSeconds = ((ret & LCA_TRACI) == 0 ?
-                                           MAX2((SUMOReal)STEPS2TIME(TS), myLeftSpace / myLookAheadSpeed / abs(bestLaneOffset) / URGENCY) :
+                                           MAX2((SUMOReal)STEPS2TIME(TS), myLeftSpace / MAX2(myLookAheadSpeed, NUMERICAL_EPS) / abs(bestLaneOffset) / URGENCY) :
                                            myVehicle.getInfluencer().changeRequestRemainingSeconds(currentTime));
         const SUMOReal plannedSpeed = informLeader(msgPass, blocked, myLca, neighLead, remainingSeconds);
         if (plannedSpeed >= 0) {
@@ -574,9 +573,12 @@ MSLCM_LC2013::_wantsChange(
         // try to use the inner lanes of a roundabout to increase throughput
         // unless we are approaching the exit
         if (lca == LCA_LEFT) {
-            return ret | lca | LCA_COOPERATIVE;
+            req = ret | lca | LCA_COOPERATIVE;
         } else {
-            return ret | LCA_STAY | LCA_COOPERATIVE;
+            req = ret | LCA_STAY | LCA_COOPERATIVE;
+        }
+        if (!cancelRequest(req)) {
+            return ret | req;
         }
     }
 
@@ -584,7 +586,10 @@ MSLCM_LC2013::_wantsChange(
     //  in this case, we do not want to get to the dead-end of an on-ramp
     if (right) {
         if (bestLaneOffset == 0 && myVehicle.getLane()->getVehicleMaxSpeed(&myVehicle) > 80. / 3.6 && myLookAheadSpeed > SUMO_const_haltingSpeed) {
-            return ret | LCA_STAY | LCA_STRATEGIC;
+            req = ret | LCA_STAY | LCA_STRATEGIC;
+            if (!cancelRequest(req)) {
+                return ret | req;
+            }
         }
     }
     // --------
@@ -599,7 +604,10 @@ MSLCM_LC2013::_wantsChange(
     if (amBlockingFollowerPlusNB()
             && (changeToBest || currentDistAllows(neighDist, abs(bestLaneOffset) + 1, laDist))) {
 
-        return ret | lca | LCA_COOPERATIVE | LCA_URGENT ;//| LCA_CHANGE_TO_HELP;
+        req = ret | lca | LCA_COOPERATIVE | LCA_URGENT ;//| LCA_CHANGE_TO_HELP;
+        if (!cancelRequest(req)) {
+            return ret | req;
+        }
     }
 
     // --------
@@ -632,10 +640,12 @@ MSLCM_LC2013::_wantsChange(
         thisLaneVSafe = MIN2(thisLaneVSafe, myCarFollowModel.followSpeed(&myVehicle, myVehicle.getSpeed(), leader.second, leader.first->getSpeed(), leader.first->getCarFollowModel().getMaxDecel()));
     }
 
-    thisLaneVSafe = MIN3(thisLaneVSafe, myVehicle.getVehicleType().getMaxSpeed(), myVehicle.getLane()->getVehicleMaxSpeed(&myVehicle));
-    neighLaneVSafe = MIN3(neighLaneVSafe, myVehicle.getVehicleType().getMaxSpeed(), neighLane.getVehicleMaxSpeed(&myVehicle));
+    const SUMOReal vMax = MIN2(myVehicle.getVehicleType().getMaxSpeed(), myVehicle.getLane()->getVehicleMaxSpeed(&myVehicle));
+    thisLaneVSafe = MIN2(thisLaneVSafe, vMax);
+    neighLaneVSafe = MIN2(neighLaneVSafe, vMax);
+    const SUMOReal relativeGain = (neighLaneVSafe - thisLaneVSafe) / MAX2(neighLaneVSafe,
+                                  RELGAIN_NORMALIZATION_MIN_SPEED);
 
-    const SUMOReal relativeGain = (neighLaneVSafe - thisLaneVSafe) / neighLaneVSafe;
     if (right) {
         // ONLY FOR CHANGING TO THE RIGHT
         if (thisLaneVSafe - 5 / 3.6 > neighLaneVSafe) {
@@ -651,44 +661,49 @@ MSLCM_LC2013::_wantsChange(
             // honor the obligation to keep right (Rechtsfahrgebot)
             // XXX consider fast approaching followers on the current lane
             //const SUMOReal vMax = myLookAheadSpeed;
-            const SUMOReal vMax = MIN2(myVehicle.getVehicleType().getMaxSpeed(), myVehicle.getLane()->getVehicleMaxSpeed(&myVehicle));
             const SUMOReal acceptanceTime = KEEP_RIGHT_ACCEPTANCE * vMax * MAX2((SUMOReal)1, myVehicle.getSpeed()) / myVehicle.getLane()->getSpeedLimit();
             SUMOReal fullSpeedGap = MAX2((SUMOReal)0, neighDist - myVehicle.getCarFollowModel().brakeGap(vMax));
             SUMOReal fullSpeedDrivingSeconds = MIN2(acceptanceTime, fullSpeedGap / vMax);
             if (neighLead.first != 0 && neighLead.first->getSpeed() < vMax) {
                 fullSpeedGap = MAX2((SUMOReal)0, MIN2(fullSpeedGap,
-                            neighLead.second - myVehicle.getCarFollowModel().getSecureGap(
-                                vMax, neighLead.first->getSpeed(), neighLead.first->getCarFollowModel().getMaxDecel())));
+                                                      neighLead.second - myVehicle.getCarFollowModel().getSecureGap(
+                                                              vMax, neighLead.first->getSpeed(), neighLead.first->getCarFollowModel().getMaxDecel())));
                 fullSpeedDrivingSeconds = MIN2(fullSpeedDrivingSeconds, fullSpeedGap / (vMax - neighLead.first->getSpeed()));
             }
             const SUMOReal deltaProb = (CHANGE_PROB_THRESHOLD_RIGHT
-                    * STEPS2TIME(DELTA_T)
-                    * (fullSpeedDrivingSeconds / acceptanceTime) / KEEP_RIGHT_TIME);
+                                        * STEPS2TIME(DELTA_T)
+                                        * (fullSpeedDrivingSeconds / acceptanceTime) / KEEP_RIGHT_TIME);
             myKeepRightProbability -= deltaProb;
 
             if (gDebugFlag2) {
                 std::cout << STEPS2TIME(currentTime)
-                    << " veh=" << myVehicle.getID()
-                    << " vMax=" << vMax
-                    << " neighDist=" << neighDist
-                    << " brakeGap=" << myVehicle.getCarFollowModel().brakeGap(myVehicle.getSpeed())
-                    << " leaderSpeed=" << (neighLead.first == 0 ? -1 : neighLead.first->getSpeed())
-                    << " secGap=" << (neighLead.first == 0 ? -1 : myVehicle.getCarFollowModel().getSecureGap(
-                                myVehicle.getSpeed(), neighLead.first->getSpeed(), neighLead.first->getCarFollowModel().getMaxDecel()))
-                    << " acceptanceTime=" << acceptanceTime
-                    << " fullSpeedGap=" << fullSpeedGap
-                    << " fullSpeedDrivingSeconds=" << fullSpeedDrivingSeconds
-                    << " dProb=" << deltaProb
-                    << "\n";
+                          << " veh=" << myVehicle.getID()
+                          << " vMax=" << vMax
+                          << " neighDist=" << neighDist
+                          << " brakeGap=" << myVehicle.getCarFollowModel().brakeGap(myVehicle.getSpeed())
+                          << " leaderSpeed=" << (neighLead.first == 0 ? -1 : neighLead.first->getSpeed())
+                          << " secGap=" << (neighLead.first == 0 ? -1 : myVehicle.getCarFollowModel().getSecureGap(
+                                                myVehicle.getSpeed(), neighLead.first->getSpeed(), neighLead.first->getCarFollowModel().getMaxDecel()))
+                          << " acceptanceTime=" << acceptanceTime
+                          << " fullSpeedGap=" << fullSpeedGap
+                          << " fullSpeedDrivingSeconds=" << fullSpeedDrivingSeconds
+                          << " dProb=" << deltaProb
+                          << "\n";
             }
             if (myKeepRightProbability < -CHANGE_PROB_THRESHOLD_RIGHT) {
-                return ret | lca | LCA_KEEPRIGHT;
+                req = ret | lca | LCA_KEEPRIGHT;
+                if (!cancelRequest(req)) {
+                    return ret | req;
+                }
             }
         }
 
         if (mySpeedGainProbability < -CHANGE_PROB_THRESHOLD_RIGHT
                 && neighDist / MAX2((SUMOReal) .1, myVehicle.getSpeed()) > 20.) { //./MAX2((SUMOReal) .1, myVehicle.getSpeed())) { // -.1
-            return ret | lca | LCA_SPEEDGAIN;
+            req = ret | lca | LCA_SPEEDGAIN;
+            if (!cancelRequest(req)) {
+                return ret | req;
+            }
         }
     } else {
         // ONLY FOR CHANGING TO THE LEFT
@@ -702,14 +717,20 @@ MSLCM_LC2013::_wantsChange(
             mySpeedGainProbability += relativeGain;
         }
         if (mySpeedGainProbability > CHANGE_PROB_THRESHOLD_LEFT && neighDist / MAX2((SUMOReal) .1, myVehicle.getSpeed()) > 20.) { // .1
-            return ret | lca | LCA_SPEEDGAIN;
+            req = ret | lca | LCA_SPEEDGAIN;
+            if (!cancelRequest(req)) {
+                return ret | req;
+            }
         }
     }
     // --------
     if (changeToBest && bestLaneOffset == curr.bestLaneOffset
             && (right ? mySpeedGainProbability < 0 : mySpeedGainProbability > 0)) {
         // change towards the correct lane, speedwise it does not hurt
-        return ret | lca | LCA_STRATEGIC;
+        req = ret | lca | LCA_STRATEGIC;
+        if (!cancelRequest(req)) {
+            return ret | req;
+        }
     }
 
     return ret;
