@@ -8,7 +8,7 @@
 /// @author  Michael Behrisch
 /// @author  Mario Krumnow
 /// @date    Mon, 12 Mar 2001
-/// @version $Id: MSLane.h 15727 2014-02-25 08:09:54Z behrisch $
+/// @version $Id: MSLane.h 16560 2014-06-09 20:54:15Z behrisch $
 ///
 // Representation of a lane in the micro simulation
 /****************************************************************************/
@@ -388,6 +388,8 @@ public:
     }
     /// @}
 
+    /// @brief return the index of the link to the next crossing if this is walkingArea, else -1
+    int getCrossingIndex() const;
 
 
     /// @name Vehicle movement (longitudinal)
@@ -624,6 +626,11 @@ public:
 
     MSLane* getLogicalPredecessorLane() const;
 
+    /// @brief get the state of the link from the logical predecessor to this lane
+    LinkState getIncomingLinkState() const;
+
+    /// @brief get the list of outgoing lanes
+    std::vector<const MSLane*> getOutgoingLanes() const;
 
     /// @name Current state retrieval
     //@{
