@@ -7,7 +7,7 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    2004-11-23
-/// @version $Id: MSInductLoop.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: MSInductLoop.cpp 16492 2014-06-03 13:08:10Z namdre $
 ///
 // An unextended detector measuring at a fixed position on a fixed lane.
 /****************************************************************************/
@@ -99,9 +99,13 @@ MSInductLoop::notifyMove(SUMOVehicle& veh, SUMOReal oldPos,
         enterDetectorByMove(veh, entryTime);
     }
     if (newPos - veh.getVehicleType().getLength() > myPosition) {
-        // vehicle passed the detector
+        // vehicle passed the detector (it may have changed onto this lane
+        // somewhere past the detector)
+        assert(newSpeed > 0 || myVehiclesOnDet.find(&veh) == myVehiclesOnDet.end());
         SUMOReal leaveTime = STEPS2TIME(MSNet::getInstance()->getCurrentTimeStep());
-        leaveTime += (myPosition - oldPos + veh.getVehicleType().getLength()) / newSpeed;
+        if (newSpeed > 0) {
+            leaveTime += (myPosition - oldPos + veh.getVehicleType().getLength()) / newSpeed;
+        }
         leaveDetectorByMove(veh, leaveTime);
         return false;
     }
