@@ -4,7 +4,7 @@
 /// @author  Jakob Erdmann
 /// @author  Michael Behrisch
 /// @date    Mon, 9 Jul 2001
-/// @version $Id: NLJunctionControlBuilder.h 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: NLJunctionControlBuilder.h 16290 2014-05-05 12:38:38Z namdre $
 ///
 // Builder of microsim-junctions and tls
 /****************************************************************************/
@@ -262,6 +262,9 @@ public:
     /// @brief initialize junctions after all connections have been loaded
     void postLoadInitialization();
 
+    /// @brief try to retrieve junction by id
+    MSJunction* retrieve(const std::string id);
+
 
 protected:
     /** @brief Returns the current junction logic
