@@ -5,7 +5,7 @@
 /// @author  Christoph Sommer
 /// @author  Michael Behrisch
 /// @date    Thu, 02.11.2006
-/// @version $Id: PCLoaderXML.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: PCLoaderXML.cpp 16275 2014-04-29 11:43:40Z behrisch $
 ///
 // A reader for polygons and pois stored in XML-format
 /****************************************************************************/
@@ -71,7 +71,7 @@ PCLoaderXML::loadIfSet(OptionsCont& oc, PCPolyContainer& toFill,
     // parse file(s)
     std::vector<std::string> files = oc.getStringVector("xml");
     for (std::vector<std::string>::const_iterator file = files.begin(); file != files.end(); ++file) {
-        if (!FileHelpers::exists(*file)) {
+        if (!FileHelpers::isReadable(*file)) {
             throw ProcessError("Could not open xml-file '" + *file + "'.");
         }
         PROGRESS_BEGIN_MESSAGE("Parsing XML from '" + *file + "'");
