@@ -8,13 +8,16 @@
 /// @author  Tino Morenz
 /// @author  Michael Behrisch
 /// @author  Christoph Sommer
+/// @author  Mario Krumnow
+/// @author  Jakob Erdmann
+/// @author  Laura Bieker
 /// @date    2007/10/24
-/// @version $Id: TraCIConstants.h 15703 2014-02-23 14:31:00Z behrisch $
+/// @version $Id: TraCIConstants.h 16331 2014-05-08 17:59:28Z mkrumnow $
 ///
 /// holds codes used for TraCI
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2007-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -478,6 +481,9 @@
 // position (2D) (get: vehicle, poi, set: poi)
 #define VAR_POSITION 0x42
 
+// position (3D) (get: vehicle, poi, set: poi)
+#define VAR_POSITION3D 0x39
+
 // angle (get: vehicle)
 #define VAR_ANGLE 0x43
 
