@@ -2,7 +2,7 @@
 /// @file    SysUtils.h
 /// @author  Daniel Krajzewicz
 /// @date    Fri, 29.04.2005
-/// @version $Id: SysUtils.h 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: SysUtils.h 15974 2014-03-19 13:47:12Z namdre $
 ///
 // A few system-specific functions
 /****************************************************************************/
@@ -30,6 +30,7 @@
 #include <config.h>
 #endif
 
+#include <string>
 
 // ===========================================================================
 // class definitions
@@ -54,8 +55,10 @@ public:
     static long getWindowsTicks();
 #endif
 
-};
 
+    /// @brief run a shell command without popping up any windows (particuarly on win32)
+    static unsigned long runHiddenCommand(const std::string& cmd);
+};
 
 #endif
 
