@@ -6,7 +6,7 @@
 /// @author  Laura Bieker
 /// @author  Andreas Gaubatz
 /// @date    Sept 2002
-/// @version $Id: GUISUMOAbstractView.cpp 15692 2014-02-22 09:17:02Z behrisch $
+/// @version $Id: GUISUMOAbstractView.cpp 15990 2014-03-21 20:58:19Z behrisch $
 ///
 // The base class for a view
 /****************************************************************************/
@@ -629,19 +629,21 @@ GUISUMOAbstractView::onRightBtnRelease(FXObject* o, FXSelector sel, void* data)
 
 long
 GUISUMOAbstractView::onMouseWheel(FXObject*, FXSelector , void* data) {
-    myChanger->onMouseWheel(data);
+    if (!myApp->isGaming()) {
+        myChanger->onMouseWheel(data);
+    }
     return 1;
 }
 
 
 long
 GUISUMOAbstractView::onMouseMove(FXObject*, FXSelector , void* data) {
-    SUMOReal xpos = myChanger->getXPos();
-    SUMOReal ypos = myChanger->getYPos();
-    SUMOReal zoom = myChanger->getZoom();
     if (myViewportChooser == 0 || !myViewportChooser->haveGrabbed()) {
         myChanger->onMouseMove(data);
     }
+    const SUMOReal xpos = myChanger->getXPos();
+    const SUMOReal ypos = myChanger->getYPos();
+    const SUMOReal zoom = myChanger->getZoom();
     if (myViewportChooser != 0 &&
             (xpos != myChanger->getXPos() || ypos != myChanger->getYPos() || zoom != myChanger->getZoom())) {
         myViewportChooser->setValues(myChanger->getZoom(), myChanger->getXPos(), myChanger->getYPos());
