@@ -6,12 +6,12 @@
 /// @author  Michael Behrisch
 /// @author  Laura Bieker
 /// @date    Mon, 07.04.2008
-/// @version $Id: SUMOVehicleParserHelper.cpp 15699 2014-02-22 16:33:39Z behrisch $
+/// @version $Id: SUMOVehicleParserHelper.cpp 16381 2014-05-14 12:31:03Z namdre $
 ///
 // Helper methods for parsing vehicle attributes
 /****************************************************************************/
 // SUMO, Simulation of Urban MObility; see http://sumo-sim.org/
-// Copyright (C) 2001-2014 DLR (http://www.dlr.de/) and contributors
+// Copyright (C) 2008-2014 DLR (http://www.dlr.de/) and contributors
 /****************************************************************************/
 //
 //   This file is part of SUMO.
@@ -37,6 +37,8 @@
 #include <utils/common/MsgHandler.h>
 #include <utils/common/SUMOVehicleParameter.h>
 #include <utils/common/FileHelpers.h>
+#include <utils/emissions/PollutantsInterface.h>
+#include <utils/options/OptionsCont.h>
 #include "SUMOVehicleParserHelper.h"
 
 #ifdef CHECK_MEMORY_LEAKS
@@ -50,7 +52,6 @@
 SUMOVehicleParserHelper::CFAttrMap SUMOVehicleParserHelper::allowedCFModelAttrs;
 
 
-
 // ===========================================================================
 // method definitions
 // ===========================================================================
@@ -63,10 +64,21 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
                            "' and '" + attrs.getName(SUMO_ATTR_VEHSPERHOUR) +
                            "' has to be given in the definition of flow '" + id + "'.");
     }
-    if (attrs.hasAttribute(SUMO_ATTR_PERIOD) || attrs.hasAttribute(SUMO_ATTR_VEHSPERHOUR)) {
+    if (attrs.hasAttribute(SUMO_ATTR_PERIOD) && attrs.hasAttribute(SUMO_ATTR_PROB)) {
+        throw ProcessError("At most one of '" + attrs.getName(SUMO_ATTR_PERIOD) +
+                           "' and '" + attrs.getName(SUMO_ATTR_PROB) +
+                           "' has to be given in the definition of flow '" + id + "'.");
+    }
+    if (attrs.hasAttribute(SUMO_ATTR_PROB) && attrs.hasAttribute(SUMO_ATTR_VEHSPERHOUR)) {
+        throw ProcessError("At most one of '" + attrs.getName(SUMO_ATTR_PROB) +
+                           "' and '" + attrs.getName(SUMO_ATTR_VEHSPERHOUR) +
+                           "' has to be given in the definition of flow '" + id + "'.");
+    }
+    if (attrs.hasAttribute(SUMO_ATTR_PERIOD) || attrs.hasAttribute(SUMO_ATTR_VEHSPERHOUR) || attrs.hasAttribute(SUMO_ATTR_PROB)) {
         if (attrs.hasAttribute(SUMO_ATTR_END) && attrs.hasAttribute(SUMO_ATTR_NUMBER)) {
             throw ProcessError("If '" + attrs.getName(SUMO_ATTR_PERIOD) +
-                               "' or '" + attrs.getName(SUMO_ATTR_VEHSPERHOUR) +
+                               "', '" + attrs.getName(SUMO_ATTR_VEHSPERHOUR) +
+                               "' or '" + attrs.getName(SUMO_ATTR_PROB) +
                                "' are given at most one of '" + attrs.getName(SUMO_ATTR_END) +
                                "' and '" + attrs.getName(SUMO_ATTR_NUMBER) +
                                "' are allowed in flow '" + id + "'.");
@@ -75,6 +87,7 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
         if (!attrs.hasAttribute(SUMO_ATTR_NUMBER)) {
             throw ProcessError("At least one of '" + attrs.getName(SUMO_ATTR_PERIOD) +
                                "', '" + attrs.getName(SUMO_ATTR_VEHSPERHOUR) +
+                               "', '" + attrs.getName(SUMO_ATTR_PROB) +
                                "', and '" + attrs.getName(SUMO_ATTR_NUMBER) +
                                "' is needed in flow '" + id + "'.");
         }
@@ -108,6 +121,13 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
             ret->repetitionOffset = TIME2STEPS(3600. / vph);
         }
     }
+    if (attrs.hasAttribute(SUMO_ATTR_PROB)) {
+        ret->repetitionProbability = attrs.get<SUMOReal>(SUMO_ATTR_PROB, id.c_str(), ok);
+        if (ok && (ret->repetitionProbability < 0 || ret->repetitionProbability > 1)) {
+            delete ret;
+            throw ProcessError("Invalid repetition probability in the definition of flow '" + id + "'.");
+        }
+    }
 
     ret->depart = beginDefault;
     if (attrs.hasAttribute(SUMO_ATTR_BEGIN)) {
@@ -143,14 +163,19 @@ SUMOVehicleParserHelper::parseFlowAttributes(const SUMOSAXAttributes& attrs, con
             }
         }
     } else {
-        if (ok && ret->repetitionOffset <= 0) {
-            delete ret;
-            throw ProcessError("Invalid repetition rate in the definition of flow '" + id + "'.");
-        }
-        if (end == SUMOTime_MAX) {
+        // interpret repetitionNumber
+        if (ok && ret->repetitionProbability >= 0) {
             ret->repetitionNumber = INT_MAX;
         } else {
-            ret->repetitionNumber = static_cast<int>(static_cast<SUMOReal>(end - ret->depart) / ret->repetitionOffset + 0.5);
+            if (ok && ret->repetitionOffset <= 0) {
+                delete ret;
+                throw ProcessError("Invalid repetition rate in the definition of flow '" + id + "'.");
+            }
+            if (end == SUMOTime_MAX) {
+                ret->repetitionNumber = INT_MAX;
+            } else {
+                ret->repetitionNumber = static_cast<int>(static_cast<SUMOReal>(end - ret->depart) / ret->repetitionOffset + 0.5);
+            }
         }
     }
     if (!ok) {
@@ -293,9 +318,13 @@ SUMOVehicleParserHelper::parseCommonAttributes(const SUMOSAXAttributes& attrs,
 
 SUMOVTypeParameter*
 SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const std::string& file) {
-    SUMOVTypeParameter* vtype = new SUMOVTypeParameter();
     bool ok = true;
-    vtype->id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    std::string id = attrs.get<std::string>(SUMO_ATTR_ID, 0, ok);
+    SUMOVehicleClass vClass = SVC_IGNORING;
+    if (attrs.hasAttribute(SUMO_ATTR_VCLASS)) {
+        vClass = parseVehicleClass(attrs, id);
+    }
+    SUMOVTypeParameter* vtype = new SUMOVTypeParameter(id, vClass);
     if (attrs.hasAttribute(SUMO_ATTR_LENGTH)) {
         vtype->length = attrs.get<SUMOReal>(SUMO_ATTR_LENGTH, vtype->id.c_str(), ok);
         vtype->setParameter |= VTYPEPARS_LENGTH_SET;
@@ -329,7 +358,6 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
         vtype->setParameter |= VTYPEPARS_IMPATIENCE_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_VCLASS)) {
-        vtype->vehicleClass = parseVehicleClass(attrs, vtype->id);
         vtype->setParameter |= VTYPEPARS_VEHICLECLASS_SET;
     }
     if (attrs.hasAttribute(SUMO_ATTR_WIDTH)) {
@@ -369,7 +397,7 @@ SUMOVehicleParserHelper::beginVTypeParsing(const SUMOSAXAttributes& attrs, const
         const std::string lcmS = attrs.get<std::string>(SUMO_ATTR_LANE_CHANGE_MODEL, vtype->id.c_str(), ok);
         if (SUMOXMLDefinitions::LaneChangeModels.hasString(lcmS)) {
             vtype->lcModel = SUMOXMLDefinitions::LaneChangeModels.get(lcmS);
-            vtype->setParameter |= VTYPEPARS_LCM_SET;
+            vtype->setParameter |= VTYPEPARS_LANE_CHANGE_MODEL_SET;
         } else {
             WRITE_ERROR("Unknown lane change model '" + lcmS + "' when parsing vtype '" + vtype->id + "'");
             throw ProcessError();
@@ -512,14 +540,19 @@ SUMOVehicleParserHelper::getAllowedCFModelAttrs() {
 SUMOVehicleClass
 SUMOVehicleParserHelper::parseVehicleClass(const SUMOSAXAttributes& attrs,
         const std::string& id) {
-    SUMOVehicleClass vclass = SVC_UNKNOWN;
+    SUMOVehicleClass vclass = SVC_IGNORING;
     try {
         bool ok = true;
         std::string vclassS = attrs.getOpt<std::string>(SUMO_ATTR_VCLASS, id.c_str(), ok, "");
         if (vclassS == "") {
             return vclass;
         }
-        return getVehicleClassID(vclassS);
+        const SUMOVehicleClass result = getVehicleClassID(vclassS);
+        const std::string& realName = SumoVehicleClassStrings.getString(result);
+        if (realName != vclassS) {
+            WRITE_WARNING("The vehicle class '" + vclassS + "' for " + attrs.getObjectType() + " '" + id + "' is deprecated, use '" + realName + "' instead.");
+        }
+        return result;
     } catch (...) {
         WRITE_ERROR("The class for " + attrs.getObjectType() + " '" + id + "' is not known.");
     }
@@ -532,10 +565,10 @@ SUMOVehicleParserHelper::parseEmissionClass(const SUMOSAXAttributes& attrs, cons
     try {
         bool ok = true;
         std::string eClassS = attrs.getOpt<std::string>(SUMO_ATTR_EMISSIONCLASS, id.c_str(), ok, "");
-        return getVehicleEmissionTypeID(eClassS);
+        return PollutantsInterface::getClassByName(eClassS);
     } catch (...) {
         WRITE_ERROR("The emission class for " + attrs.getObjectType() + " '" + id + "' is not known.");
-        return SVE_UNKNOWN;
+        return 0;
     }
 }
 
@@ -545,7 +578,12 @@ SUMOVehicleParserHelper::parseGuiShape(const SUMOSAXAttributes& attrs, const std
     bool ok = true;
     std::string vclassS = attrs.getOpt<std::string>(SUMO_ATTR_GUISHAPE, id.c_str(), ok, "");
     if (SumoVehicleShapeStrings.hasString(vclassS)) {
-        return SumoVehicleShapeStrings.get(vclassS);
+        const SUMOVehicleShape result = SumoVehicleShapeStrings.get(vclassS);
+        const std::string& realName = SumoVehicleShapeStrings.getString(result);
+        if (realName != vclassS) {
+            WRITE_WARNING("The shape '" + vclassS + "' for " + attrs.getObjectType() + " '" + id + "' is deprecated, use '" + realName + "' instead.");
+        }
+        return result;
     } else {
         WRITE_ERROR("The shape '" + vclassS + "' for " + attrs.getObjectType() + " '" + id + "' is not known.");
         return SVS_UNKNOWN;
